==> solana-lib-2.0.0.tgz: package/src/components/Header/index.tsx <==
import React, { useState } from "react";
import type { FC } from "react";
import type { HeaderProps } from "./header.types";
import Image from "next/image";
import {Section} from "../../molecules/Section";

import { DesktopNav } from './Navbar/Desktop/DesktopNav'
import { MobileNav } from "./Navbar/Mobile/MobileNav";

import { Hamburger } from "./Navbar/Mobile/HamburgerMenu";

import Link from "next/link";

import useMediaQuery from "../../utils/hooks/useMediaQuery";
import useOpenState from "../../utils/hooks/useOpenState";

export const Header: FC<HeaderProps> = ({ menus, solanaLogo }) => {
  const [openMenu, setOpenMenu] = useState<number | null>(null);
  const [isMobileNavOpen, setIsMobileNavOpen] = useOpenState();
  const isDesktop = useMediaQuery("lg");

  return (
    <header
      className="tw-sticky tw-top-0 tw-left-0"
      onMouseLeave={() => setOpenMenu(null)}
    >
      <nav className="tw-relative tw-z-100 tw-isolate">
        <Section
          wrapperClass="tw-bg-common-black"
          className="tw-flex tw-justify-between tw-items-center tw-min-h-[72px] tw-py-0 sm:tw-py-0 md:tw-py-0 lg:tw-py-0"
        >
          <Link href="/">
            <Image
              src={solanaLogo || ""}
              alt="Solana Logo"
              width={149}
              height={22}
              priority
            />
          </Link>
          {isDesktop && menus ? (
            <DesktopNav
              menus={menus}
              setOpenMenu={setOpenMenu}
              openMenu={openMenu}
            />
          ) : (
            <Hamburger
              isMobileNavOpen={isMobileNavOpen}
              setIsMobileNavOpen={setIsMobileNavOpen}
            />
          )}
        </Section>
        {!isDesktop && menus && (
          <MobileNav menus={menus} isMobileNavOpen={isMobileNavOpen} />
        )}
      </nav>
    </header>
  );
};

==> solana-lib-2.6.6.tgz: package/src/components/Header/index.tsx <==
import React, { useState } from "react";
import type { FC } from "react";
import type { HeaderProps } from "./header.types";
import Image from "next/image";
import {Section} from "../../molecules/Section";

import { DesktopNav } from './Navbar/Desktop/DesktopNav'
import { MobileNav } from "./Navbar/Mobile/MobileNav";

import { Hamburger } from "./Navbar/Mobile/HamburgerMenu";

import Link from "next/link";

import useMediaQuery from "../../utils/hooks/useMediaQuery";
import useOpenState from "../../utils/hooks/useOpenState";

export const Header: FC<HeaderProps> = ({ menus, solanaLogo }) => {
  const [openMenu, setOpenMenu] = useState<number | null>(null);
  const [isMobileNavOpen, setIsMobileNavOpen] = useOpenState();
  const isDesktop = useMediaQuery("lg");

  return (
    <header
      className="tw-sticky tw-top-0 tw-left-0 tw-z-10"
      onMouseLeave={() => setOpenMenu(null)}
    >
      <nav className="tw-relative tw-z-100 tw-isolate">
        <Section
          wrapperClass="tw-bg-common-black"
          className="tw-flex tw-justify-between tw-items-center tw-min-h-[72px] tw-py-0 sm:tw-py-0 md:tw-py-0 lg:tw-py-0"
        >
          <Link href="/">
            <Image
              src={solanaLogo || ""}
              alt="Solana Logo"
              width={149}
              height={22}
              priority
            />
          </Link>
          {isDesktop && menus ? (
            <DesktopNav
              menus={menus}
              setOpenMenu={setOpenMenu}
              openMenu={openMenu}
            />
          ) : (
            <Hamburger
              isMobileNavOpen={isMobileNavOpen}
              setIsMobileNavOpen={setIsMobileNavOpen}
            />
          )}
        </Section>
        {!isDesktop && menus && (
          <MobileNav menus={menus} isMobileNavOpen={isMobileNavOpen} />
        )}
      </nav>
    </header>
  );
};
